@@ -5,7 +5,7 @@ import docker
 import urllib.request
 import yaml
 from .static import DOCKERFILE, SERVER
-from .docker_logic import build, push, start
+from .docker_logic import build, push, run
 
 @click.group()
 def cli():
@@ -13,4 +13,4 @@ def cli():
 
 cli.add_command(build, name="build")
 cli.add_command(push, name="push")
-cli.add_command(start, name="start")
+cli.add_command(run, name="run")
\ No newline at end of file
